package org.xmldb.xupdate.lexus.commands;

/*
 *  The XML:DB Initiative Software License, Version 1.0
 *
 *
 * Copyright (c) 2000-2003 The XML:DB Initiative.  All rights
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by the
 *        XML:DB Initiative (http://www.xmldb.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "XML:DB Initiative" must not be used to endorse or
 *    promote products derived from this software without prior written
 *    permission. For written permission, please contact info@xmldb.org.
 *
 * 5. Products derived from this software may not be called "XML:DB",
 *    nor may "XML:DB" appear in their name, without prior written
 *    permission of the XML:DB Initiative.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the XML:DB Initiative. For more information
 * on the XML:DB Initiative, please see <http://www.xmldb.org/>.
 */

import org.w3c.dom.Attr;
import org.w3c.dom.Comment;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;

import org.apache.log4j.Category;

/**
 *
 * @version $Id: UpdateCommand.java,v 1.4 2003/05/21 08:17:38 jbreedveld Exp $
 * @author <a href="http://www.smb-tec.com">SMB</a>
 */
public class UpdateCommand extends CommandObject {
  Category log = Category.getInstance(UpdateCommand.class);


  /**
   *
   */
  public UpdateCommand(Node contextNode) throws Exception {
    super(contextNode);
  }


  /**
   * @return Always <code>false</code>.
   */
  public boolean submitInstruction(int instruction) {
    //does nothing
    return false;
  }


  /**
   * @return Always <code>false</code>.
   */
  public boolean executeInstruction() {
    //does nothing
    return false;
  }


  /**
   *
   */
  public Node execute() throws Exception {
    String data = "";
    for (int i = 0; i < characters.size(); i++) {
      data += (String) characters.elementAt(i);
    }
    String selection = (String) attributes.get("select");
    selectNodes(selection);
    int selectionLength = selectionNodeList.getLength();
    for (int i = 0; i < selectionNodeList.getLength(); i++) {
      Node current = selectionNodeList.item(i);
      switch (current.getNodeType()) {
        case Node.ELEMENT_NODE:
          current.normalize();
          NodeList children = current.getChildNodes();
          int childrenLength = children.getLength();
          for (int j = childrenLength -1 ; j >= 0; j--) {
            log.debug(".execute(): Remove child (" + j + "): " +  children.item(j).getNodeType());
            if (children.item(j).getNodeType() == Node.TEXT_NODE) {
              log.debug(".execute(): TEXT_NODE: " +  children.item(j).getNodeValue());
            }
            current.removeChild(children.item(j));
          }
          if (characters.size() > 0) {
            current.appendChild(document.createTextNode(data));
          }
          break;
        case Node.TEXT_NODE:
          if (characters.size() > 0) {
            current.setNodeValue(data);
          } else {
            Node parent = current.getParentNode();
            parent.removeChild(current);
          }
          break;
        case Node.COMMENT_NODE:
          ((Comment) current).setData(data);
          break;
        case Node.ATTRIBUTE_NODE:
          ((Attr) current).setValue(data);
          break;
        default:
          if (characters.size() == 0) {
            throw new Exception("[update] new values must not be empty !");
          }
          current.setNodeValue(data);
      }
    }
    return contextNode;
  }
}
